#include "my_check_params.hpp" 

// Гарантируется наличие минимума нужных аргументов для flood и scan
// Гарантируется, что после работы парсера мы получим только валидный тип атаки 

// Добавить:
// 1. Валидацию IP, port

// Статус коды:
// 2 - Атака флуд, все нужные опции есть
// 1 - Атака порт скан, все нужные опции есть
// 0 - нужна помощь
// -1 - пользователь не ввел тип атаки или ввел неверный тип атаки
// -10 - Пользователь выбрал тип атаки порт сканнинг, но не ввел нужные параметры
// -20 - Пользователь выбрал тип атаки флуд, но не ввел нужные параметры
// -100 - неизвестная ошибка
// -101 - неизвестная опция, следует предложить вызвать флаг помощи
// Какие-то еще коды?
int my_check_params(int argc, char** argv) {

    int status = -100;
    // Короткие опции (с двоеточием для параметров)
    const char* short_options = "a:d:i:p:l:t:b:h";
    
    // Длинные опции
    const struct option long_options[] = {
        {"attack",    required_argument, NULL, 'a'},
        {"domain",    required_argument, NULL, 'd'},
        {"ip",        required_argument, NULL, 'i'},
        {"port",      required_argument, NULL, 'p'},
        {"log",       required_argument, NULL, 'l'},
        {"telegram",  required_argument, NULL, 't'},
        {"token",     required_argument, NULL, 'b'},
        {"help",      no_argument,       NULL, 'h'},
        {NULL,     0,                 NULL,  0}
    };

    int opt;
    while ((opt = getopt_long(argc, argv, short_options, long_options, NULL)) != -1) {
        switch (opt) {
            case 'a':
                opts.attack_type = optarg;
                break;
            case 'd':
                opts.domain = optarg;
                break;
            case 'i':
                opts.ip = optarg;
                break;
            case 'p':
                opts.port = optarg;
                break;
            case 'l':
                opts.log_file = optarg;
                break;
            case 't':
                opts.telegram_id = optarg;
                break;
            case 'b':
                opts.telegram_token = optarg;
                break;
            case 'h':
                std::cout << "Usage: " << argv[0] << " [options]\n"
                          << "Required:\n"
                          << "  -a, --attack TYPE    Type of attack (scan|flood)\n"
                          << "  -d, --domain DOMAIN  Target domain\n"
                          << "  -i, --ip IP          Target IP\n"
                          << "  -p, --port PORT      Port. Required only for flood type!\n"
                          << "Optional:\n"
                          << "  -l, --log FILE       Log file\n"
                          << "  -t, --telegram ID    Telegram ID\n"
                          << "  -b, --token TOKEN    Telegram bot token\n";
                status = 0;
                break;
            case '?':
                std::cerr << "Unknown option!\n.--help for info\n";
                status = -101;
                break;
            default:
                status = -100;
                break;
        }
    }

    // Проверка обязательных параметров
    
    if (status != 0)
    {
        if (opts.attack_type != "flood" && opts.attack_type != "scan") {
            std::cerr << "Error: Missing required parameters!\n--help for more info\n";
            status = -1;
        }
        else if (opts.attack_type == "scan" && (opts.domain.empty() || opts.ip.empty())) {
            std::cerr << "Error: Missing required parameters!\n--help for more info\n";
            status = -10;
        }
        else if (opts.attack_type == "flood" && (opts.domain.empty() || opts.ip.empty() || opts.port.empty())) {
            std::cerr << "Error: Missing required parameters!\n--help for more info\n";
            status = -20;
        }
        else if (opts.attack_type == "scan" && !opts.domain.empty() && !opts.ip.empty()) {
            std::cerr << "Error: Missing required parameters!\n--help for more info\n";
            status = 1;
        }
        else if (opts.attack_type == "flood" && !opts.domain.empty() && !opts.ip.empty() && !opts.port.empty()) {
            std::cerr << "Error: Missing required parameters!\n--help for more info\n";
            status = 2;
        }
        // Какие-то еще коды?
    }
    




    return status;
}